@@ -61,6 +61,7 @@ sub _alias_preference {
 
 package # hide from PAUSE
     DBIx::DBO::Table::DBD::mysql;
+use Carp 'croak';
 
 sub _save_last_insert_id {
     my $me = shift;
@@ -68,6 +69,10 @@ sub _save_last_insert_id {
     return $sth->{mysql_insertid};
 }
 
+sub _do_bulk_insert {
+    shift->_fast_bulk_insert(@_);
+}
+
 package # hide from PAUSE
     DBIx::DBO::Query::DBD::mysql;
 
